"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .dns_edns import DNSEDNS, DNSEDNSTypedDict
from .dns_resourcerecord import DNSResourceRecord, DNSResourceRecordTypedDict
from censys_platform.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
from enum import Enum
from pydantic import model_serializer
from typing import List, Optional
from typing_extensions import NotRequired, TypedDict


class RCode(str, Enum):
    r"""A enumerated field indicating the result of the request. The most common values are defined in RFC 1035."""

    UNKNOWN = ""
    SUCCESS = "success"
    FORMAT_ERROR = "format_error"
    SERVER_FAILURE = "server_failure"
    NAME_ERROR = "name_error"
    NOT_IMPLEMENTED = "not_implemented"
    REFUSED = "refused"
    YX_DOMAIN = "yx_domain"
    YX_RRSET = "yx_rrset"
    NX_RRSET = "nx_rrset"
    NOT_AUTH = "not_auth"
    NOT_ZONE = "not_zone"
    BAD_SIG = "bad_sig"
    BAD_KEY = "bad_key"
    BAD_TIME = "bad_time"
    BAD_MODE = "bad_mode"
    BAD_NAME = "bad_name"
    BAD_ALG = "bad_alg"
    BAD_TRUNC = "bad_trunc"
    BAD_COOKIE = "bad_cookie"


class ServerType(str, Enum):
    r"""An enumerated value indicating the behavior of the server. An AUTHORITATIVE server fulfills requests for domain names it controls, which are not listed by the server. FORWARDING and RECURSIVE_RESOLVER servers fulfill requests indirectly for domain names they do not control. A RECURSIVE_RESOLVER will query ip.parrotdns.com itself, resulting in its own IP address being present in the dns.answers.response field."""

    UNKNOWN = ""
    RECURSIVE_RESOLVER = "recursive_resolver"
    AUTHORITATIVE = "authoritative"
    FORWARDING = "forwarding"
    REDIRECTING = "redirecting"


class DNSTypedDict(TypedDict):
    additionals: NotRequired[Nullable[List[DNSResourceRecordTypedDict]]]
    r"""A list of resource records (RRs) contained in the ADDITIONAL section of the response."""
    answers: NotRequired[Nullable[List[DNSResourceRecordTypedDict]]]
    r"""A list of resource records (RRs) contained in the ANSWER section of the response."""
    authorities: NotRequired[Nullable[List[DNSResourceRecordTypedDict]]]
    r"""A list of resource records (RRs) contained in the AUTHORITIES section of the response."""
    edns: NotRequired[DNSEDNSTypedDict]
    questions: NotRequired[Nullable[List[DNSResourceRecordTypedDict]]]
    r"""A list of resource records (RRs) contained in the QUESTION section of the response, which may echo the request that the server is responding to."""
    r_code: NotRequired[RCode]
    r"""A enumerated field indicating the result of the request. The most common values are defined in RFC 1035."""
    resolves_correctly: NotRequired[bool]
    r"""Whether the server returns an IP address for ip.parrotdns.com that matches the authoritative server, which is controlled by Censys."""
    server_type: NotRequired[ServerType]
    r"""An enumerated value indicating the behavior of the server. An AUTHORITATIVE server fulfills requests for domain names it controls, which are not listed by the server. FORWARDING and RECURSIVE_RESOLVER servers fulfill requests indirectly for domain names they do not control. A RECURSIVE_RESOLVER will query ip.parrotdns.com itself, resulting in its own IP address being present in the dns.answers.response field."""
    version: NotRequired[str]


class DNS(BaseModel):
    additionals: OptionalNullable[List[DNSResourceRecord]] = UNSET
    r"""A list of resource records (RRs) contained in the ADDITIONAL section of the response."""

    answers: OptionalNullable[List[DNSResourceRecord]] = UNSET
    r"""A list of resource records (RRs) contained in the ANSWER section of the response."""

    authorities: OptionalNullable[List[DNSResourceRecord]] = UNSET
    r"""A list of resource records (RRs) contained in the AUTHORITIES section of the response."""

    edns: Optional[DNSEDNS] = None

    questions: OptionalNullable[List[DNSResourceRecord]] = UNSET
    r"""A list of resource records (RRs) contained in the QUESTION section of the response, which may echo the request that the server is responding to."""

    r_code: Optional[RCode] = None
    r"""A enumerated field indicating the result of the request. The most common values are defined in RFC 1035."""

    resolves_correctly: Optional[bool] = None
    r"""Whether the server returns an IP address for ip.parrotdns.com that matches the authoritative server, which is controlled by Censys."""

    server_type: Optional[ServerType] = None
    r"""An enumerated value indicating the behavior of the server. An AUTHORITATIVE server fulfills requests for domain names it controls, which are not listed by the server. FORWARDING and RECURSIVE_RESOLVER servers fulfill requests indirectly for domain names they do not control. A RECURSIVE_RESOLVER will query ip.parrotdns.com itself, resulting in its own IP address being present in the dns.answers.response field."""

    version: Optional[str] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = [
            "additionals",
            "answers",
            "authorities",
            "edns",
            "questions",
            "r_code",
            "resolves_correctly",
            "server_type",
            "version",
        ]
        nullable_fields = ["additionals", "answers", "authorities", "questions"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .cvssv4_components import CVSSv4Components, CVSSv4ComponentsTypedDict
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class CVSSv4TypedDict(TypedDict):
    components: NotRequired[CVSSv4ComponentsTypedDict]
    score: NotRequired[float]
    r"""Score of the vulnerability; 0.1 is the lowest, 10 is the maximum"""
    vector: NotRequired[str]
    r"""The path, method, or scenario used to exploit the vulnerability. Each section represents components that contribute to the overall CVSS score."""


class CVSSv4(BaseModel):
    components: Optional[CVSSv4Components] = None

    score: Optional[float] = None
    r"""Score of the vulnerability; 0.1 is the lowest, 10 is the maximum"""

    vector: Optional[str] = None
    r"""The path, method, or scenario used to exploit the vulnerability. Each section represents components that contribute to the overall CVSS score."""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .qcstatements_monetaryvalue import (
    QcStatementsMonetaryValue,
    QcStatementsMonetaryValueTypedDict,
)
from .qcstatements_pdslocation import (
    QcStatementsPdsLocation,
    QcStatementsPdsLocationTypedDict,
)
from .qcstatements_qclegislation import (
    QCStatementsQCLegislation,
    QCStatementsQCLegislationTypedDict,
)
from .qcstatements_qctype import QcStatementsQcType, QcStatementsQcTypeTypedDict
from censys_platform.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
from pydantic import model_serializer
from typing import List
from typing_extensions import NotRequired, TypedDict


class QcStatementsParsedStatementsTypedDict(TypedDict):
    etsi_compliance: NotRequired[Nullable[List[bool]]]
    legislation: NotRequired[Nullable[List[QCStatementsQCLegislationTypedDict]]]
    limit: NotRequired[Nullable[List[QcStatementsMonetaryValueTypedDict]]]
    pds_locations: NotRequired[Nullable[List[QcStatementsPdsLocationTypedDict]]]
    retention_period: NotRequired[Nullable[List[int]]]
    sscd: NotRequired[Nullable[List[bool]]]
    types: NotRequired[Nullable[List[QcStatementsQcTypeTypedDict]]]


class QcStatementsParsedStatements(BaseModel):
    etsi_compliance: OptionalNullable[List[bool]] = UNSET

    legislation: OptionalNullable[List[QCStatementsQCLegislation]] = UNSET

    limit: OptionalNullable[List[QcStatementsMonetaryValue]] = UNSET

    pds_locations: OptionalNullable[List[QcStatementsPdsLocation]] = UNSET

    retention_period: OptionalNullable[List[int]] = UNSET

    sscd: OptionalNullable[List[bool]] = UNSET

    types: OptionalNullable[List[QcStatementsQcType]] = UNSET

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = [
            "etsi_compliance",
            "legislation",
            "limit",
            "pds_locations",
            "retention_period",
            "sscd",
            "types",
        ]
        nullable_fields = [
            "etsi_compliance",
            "legislation",
            "limit",
            "pds_locations",
            "retention_period",
            "sscd",
            "types",
        ]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .hostasset import HostAsset, HostAssetTypedDict
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class ResponseEnvelopeHostAssetTypedDict(TypedDict):
    result: NotRequired[HostAssetTypedDict]


class ResponseEnvelopeHostAsset(BaseModel):
    result: Optional[HostAsset] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from enum import Enum
from typing import Union
from typing_extensions import TypeAliasType, TypedDict


class TargetWebOriginTypedDict(TypedDict):
    hostname: str
    r"""Hostname of the web origin"""
    port: int
    r"""Port number of the web origin"""


class TargetWebOrigin(BaseModel):
    hostname: str
    r"""Hostname of the web origin"""

    port: int
    r"""Port number of the web origin"""


class TwoTypedDict(TypedDict):
    r"""Rescan of known web property"""

    web_origin: TargetWebOriginTypedDict


class Two(BaseModel):
    r"""Rescan of known web property"""

    web_origin: TargetWebOrigin


class TargetTransportProtocol(str, Enum):
    UNKNOWN = "unknown"
    TCP = "tcp"
    UDP = "udp"
    ICMP = "icmp"
    QUIC = "quic"


class TargetServiceIDTypedDict(TypedDict):
    ip: str
    r"""IP address of service"""
    port: int
    r"""Port number of service"""
    protocol: str
    r"""Name of service protocol"""
    transport_protocol: TargetTransportProtocol


class TargetServiceID(BaseModel):
    ip: str
    r"""IP address of service"""

    port: int
    r"""Port number of service"""

    protocol: str
    r"""Name of service protocol"""

    transport_protocol: TargetTransportProtocol


class OneTypedDict(TypedDict):
    r"""Rescan of known service"""

    service_id: TargetServiceIDTypedDict


class One(BaseModel):
    r"""Rescan of known service"""

    service_id: TargetServiceID


ScansRescanInputBodyTargetTypedDict = TypeAliasType(
    "ScansRescanInputBodyTargetTypedDict", Union[OneTypedDict, TwoTypedDict]
)


ScansRescanInputBodyTarget = TypeAliasType(
    "ScansRescanInputBodyTarget", Union[One, Two]
)


class ScansRescanInputBodyTypedDict(TypedDict):
    target: ScansRescanInputBodyTargetTypedDict


class ScansRescanInputBody(BaseModel):
    target: ScansRescanInputBodyTarget



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class VentriloHeaderTypedDict(TypedDict):
    cmd: NotRequired[int]
    data_key: NotRequired[int]
    header_key: NotRequired[int]
    id: NotRequired[int]
    total_length: NotRequired[int]


class VentriloHeader(BaseModel):
    cmd: Optional[int] = None

    data_key: Optional[int] = None

    header_key: Optional[int] = None

    id: Optional[int] = None

    total_length: Optional[int] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .cpe_lifecycle import CPELifeCycle, CPELifeCycleTypedDict
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class CpeTypedDict(TypedDict):
    cpe: NotRequired[str]
    edition: NotRequired[str]
    life_cycle: NotRequired[CPELifeCycleTypedDict]
    part: NotRequired[str]
    product: NotRequired[str]
    update: NotRequired[str]
    vendor: NotRequired[str]
    version: NotRequired[str]


class Cpe(BaseModel):
    cpe: Optional[str] = None

    edition: Optional[str] = None

    life_cycle: Optional[CPELifeCycle] = None

    part: Optional[str] = None

    product: Optional[str] = None

    update: Optional[str] = None

    vendor: Optional[str] = None

    version: Optional[str] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
from pydantic import model_serializer
from typing import List, Optional
from typing_extensions import NotRequired, TypedDict


class SearchQueryInputBodyTypedDict(TypedDict):
    query: str
    r"""CenQL query string to search upon"""
    fields: NotRequired[Nullable[List[str]]]
    r"""Specify fields to only return in the response. If you provide fields and omit `host.services.port`, `host.services.transport_protocol`, and `host.services.protocol`, then `matched_services` will not be returned in the response."""
    page_size: NotRequired[Nullable[int]]
    r"""amount of results to return per page"""
    page_token: NotRequired[str]
    r"""page token for the requested page of search results"""


class SearchQueryInputBody(BaseModel):
    query: str
    r"""CenQL query string to search upon"""

    fields: OptionalNullable[List[str]] = UNSET
    r"""Specify fields to only return in the response. If you provide fields and omit `host.services.port`, `host.services.transport_protocol`, and `host.services.protocol`, then `matched_services` will not be returned in the response."""

    page_size: OptionalNullable[int] = UNSET
    r"""amount of results to return per page"""

    page_token: Optional[str] = None
    r"""page token for the requested page of search results"""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = ["fields", "page_size", "page_token"]
        nullable_fields = ["fields", "page_size"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .kubernetes_node_nodeaddress import (
    KubernetesNodeNodeAddress,
    KubernetesNodeNodeAddressTypedDict,
)
from censys_platform.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
from pydantic import model_serializer
from typing import List, Optional
from typing_extensions import NotRequired, TypedDict


class KubernetesNodeTypedDict(TypedDict):
    addresses: NotRequired[Nullable[List[KubernetesNodeNodeAddressTypedDict]]]
    architecture: NotRequired[str]
    r"""The Architecture reported by the node."""
    container_runtime_version: NotRequired[str]
    r"""ContainerRuntime Version reported by the node through runtime remote API (e.g. docker://1.5.0)."""
    images: NotRequired[Nullable[List[str]]]
    r"""List of container images on this node"""
    kernel_version: NotRequired[str]
    r"""Kernel Version reported by the node from 'uname -r' (e.g. 3.16.0-0.bpo.4-amd64)."""
    kube_proxy_version: NotRequired[str]
    r"""KubeProxy Version reported by the node."""
    kubelet_version: NotRequired[str]
    r"""Kubelet Version reported by the node."""
    name: NotRequired[str]
    operating_system: NotRequired[str]
    r"""The Operating System reported by the node."""
    os_image: NotRequired[str]
    r"""OS Image reported by the node from /etc/os-release (e.g. Debian GNU/Linux 7 (wheezy))."""


class KubernetesNode(BaseModel):
    addresses: OptionalNullable[List[KubernetesNodeNodeAddress]] = UNSET

    architecture: Optional[str] = None
    r"""The Architecture reported by the node."""

    container_runtime_version: Optional[str] = None
    r"""ContainerRuntime Version reported by the node through runtime remote API (e.g. docker://1.5.0)."""

    images: OptionalNullable[List[str]] = UNSET
    r"""List of container images on this node"""

    kernel_version: Optional[str] = None
    r"""Kernel Version reported by the node from 'uname -r' (e.g. 3.16.0-0.bpo.4-amd64)."""

    kube_proxy_version: Optional[str] = None
    r"""KubeProxy Version reported by the node."""

    kubelet_version: Optional[str] = None
    r"""Kubelet Version reported by the node."""

    name: Optional[str] = None

    operating_system: Optional[str] = None
    r"""The Operating System reported by the node."""

    os_image: Optional[str] = None
    r"""OS Image reported by the node from /etc/os-release (e.g. Debian GNU/Linux 7 (wheezy))."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = [
            "addresses",
            "architecture",
            "container_runtime_version",
            "images",
            "kernel_version",
            "kube_proxy_version",
            "kubelet_version",
            "name",
            "operating_system",
            "os_image",
        ]
        nullable_fields = ["addresses", "images"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
from pydantic import model_serializer
from typing import List, Optional
from typing_extensions import NotRequired, TypedDict


class NatsIoTypedDict(TypedDict):
    auth_required: NotRequired[bool]
    cluster: NotRequired[str]
    connect_urls: NotRequired[Nullable[List[str]]]
    domain: NotRequired[str]
    git_commit: NotRequired[str]
    go: NotRequired[str]
    headers: NotRequired[bool]
    jetstream: NotRequired[bool]
    proto: NotRequired[int]
    server_id: NotRequired[str]
    server_name: NotRequired[str]
    tls_available: NotRequired[bool]
    tls_required: NotRequired[bool]
    tls_verify: NotRequired[bool]
    version: NotRequired[str]
    ws_connect_urls: NotRequired[Nullable[List[str]]]


class NatsIo(BaseModel):
    auth_required: Optional[bool] = None

    cluster: Optional[str] = None

    connect_urls: OptionalNullable[List[str]] = UNSET

    domain: Optional[str] = None

    git_commit: Optional[str] = None

    go: Optional[str] = None

    headers: Optional[bool] = None

    jetstream: Optional[bool] = None

    proto: Optional[int] = None

    server_id: Optional[str] = None

    server_name: Optional[str] = None

    tls_available: Optional[bool] = None

    tls_required: Optional[bool] = None

    tls_verify: Optional[bool] = None

    version: Optional[str] = None

    ws_connect_urls: OptionalNullable[List[str]] = UNSET

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = [
            "auth_required",
            "cluster",
            "connect_urls",
            "domain",
            "git_commit",
            "go",
            "headers",
            "jetstream",
            "proto",
            "server_id",
            "server_name",
            "tls_available",
            "tls_required",
            "tls_verify",
            "version",
            "ws_connect_urls",
        ]
        nullable_fields = ["connect_urls", "ws_connect_urls"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class TLSChainTypedDict(TypedDict):
    fingerprint_sha256: NotRequired[str]
    r"""SHA 256 fingerprint of the certificate in the certificate chain."""
    issuer_dn: NotRequired[str]
    r"""Distinguished name of the entity that has signed and issued the certificate."""
    subject_dn: NotRequired[str]
    r"""Distinguished name of the entity that the certificate belongs to."""


class TLSChain(BaseModel):
    fingerprint_sha256: Optional[str] = None
    r"""SHA 256 fingerprint of the certificate in the certificate chain."""

    issuer_dn: Optional[str] = None
    r"""Distinguished name of the entity that has signed and issued the certificate."""

    subject_dn: Optional[str] = None
    r"""Distinguished name of the entity that the certificate belongs to."""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .mqtt_connectionackreturn import (
    MqttConnectionAckReturn,
    MqttConnectionAckReturnTypedDict,
)
from .mqtt_subscriptionackreturn import (
    MqttSubscriptionAckReturn,
    MqttSubscriptionAckReturnTypedDict,
)
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class MqttTypedDict(TypedDict):
    connection_ack_raw: NotRequired[str]
    r"""Raw CONNACK response packet"""
    connection_ack_return: NotRequired[MqttConnectionAckReturnTypedDict]
    subscription_ack_return: NotRequired[MqttSubscriptionAckReturnTypedDict]


class Mqtt(BaseModel):
    connection_ack_raw: Optional[str] = None
    r"""Raw CONNACK response packet"""

    connection_ack_return: Optional[MqttConnectionAckReturn] = None

    subscription_ack_return: Optional[MqttSubscriptionAckReturn] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .certificateextensions import CertificateExtensions, CertificateExtensionsTypedDict
from .distinguishedname import DistinguishedName, DistinguishedNameTypedDict
from .extension import Extension, ExtensionTypedDict
from .signature import Signature, SignatureTypedDict
from .subjectkeyinfo import SubjectKeyInfo, SubjectKeyInfoTypedDict
from .validityperiod import ValidityPeriod, ValidityPeriodTypedDict
from censys_platform.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
from pydantic import model_serializer
from typing import List, Optional
from typing_extensions import NotRequired, TypedDict


class CertificateParsedTypedDict(TypedDict):
    extensions: NotRequired[CertificateExtensionsTypedDict]
    issuer: NotRequired[DistinguishedNameTypedDict]
    issuer_dn: NotRequired[str]
    r"""Distinguished Name of the entity that has signed and issued the certificate."""
    ja4x: NotRequired[str]
    redacted: NotRequired[bool]
    serial_number: NotRequired[str]
    r"""Issuer-specific identifier of the certificate."""
    serial_number_hex: NotRequired[str]
    r"""Issuer-specific identifier of the certificate, represented as hexadecimal."""
    signature: NotRequired[SignatureTypedDict]
    subject: NotRequired[DistinguishedNameTypedDict]
    subject_dn: NotRequired[str]
    r"""Distinguished Name of the entity associated with the public key."""
    subject_key_info: NotRequired[SubjectKeyInfoTypedDict]
    unknown_extensions: NotRequired[Nullable[List[ExtensionTypedDict]]]
    validity_period: NotRequired[ValidityPeriodTypedDict]
    version: NotRequired[int]


class CertificateParsed(BaseModel):
    extensions: Optional[CertificateExtensions] = None

    issuer: Optional[DistinguishedName] = None

    issuer_dn: Optional[str] = None
    r"""Distinguished Name of the entity that has signed and issued the certificate."""

    ja4x: Optional[str] = None

    redacted: Optional[bool] = None

    serial_number: Optional[str] = None
    r"""Issuer-specific identifier of the certificate."""

    serial_number_hex: Optional[str] = None
    r"""Issuer-specific identifier of the certificate, represented as hexadecimal."""

    signature: Optional[Signature] = None

    subject: Optional[DistinguishedName] = None

    subject_dn: Optional[str] = None
    r"""Distinguished Name of the entity associated with the public key."""

    subject_key_info: Optional[SubjectKeyInfo] = None

    unknown_extensions: OptionalNullable[List[Extension]] = UNSET

    validity_period: Optional[ValidityPeriod] = None

    version: Optional[int] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = [
            "extensions",
            "issuer",
            "issuer_dn",
            "ja4x",
            "redacted",
            "serial_number",
            "serial_number_hex",
            "signature",
            "subject",
            "subject_dn",
            "subject_key_info",
            "unknown_extensions",
            "validity_period",
            "version",
        ]
        nullable_fields = ["unknown_extensions"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .snmp_system_services import SnmpSystemServices, SnmpSystemServicesTypedDict
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class SnmpSystemTypedDict(TypedDict):
    contact: NotRequired[str]
    r"""1.3.6.1.2.1.1.4 - Contact info"""
    desc: NotRequired[str]
    r"""1.3.6.1.2.1.1.1 - Description of entity"""
    init_time: NotRequired[int]
    r"""1.3.6.1.2.1.1.3 - 1/100ths of sec"""
    location: NotRequired[str]
    r"""1.3.6.1.2.1.1.6 - Physical location"""
    name: NotRequired[str]
    r"""1.3.6.1.2.1.1.5 - Name, usually FQDN"""
    object_id: NotRequired[str]
    r"""1.3.6.1.2.1.1.2 - Vendor ID"""
    services: NotRequired[SnmpSystemServicesTypedDict]


class SnmpSystem(BaseModel):
    contact: Optional[str] = None
    r"""1.3.6.1.2.1.1.4 - Contact info"""

    desc: Optional[str] = None
    r"""1.3.6.1.2.1.1.1 - Description of entity"""

    init_time: Optional[int] = None
    r"""1.3.6.1.2.1.1.3 - 1/100ths of sec"""

    location: Optional[str] = None
    r"""1.3.6.1.2.1.1.6 - Physical location"""

    name: Optional[str] = None
    r"""1.3.6.1.2.1.1.5 - Name, usually FQDN"""

    object_id: Optional[str] = None
    r"""1.3.6.1.2.1.1.2 - Vendor ID"""

    services: Optional[SnmpSystemServices] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing_extensions import TypedDict


class RawCertificateResponseTypedDict(TypedDict):
    certificate_id: str
    pem: str


class RawCertificateResponse(BaseModel):
    certificate_id: str

    pem: str



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .lpdmessage import LpdMessage, LpdMessageTypedDict
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class LpdTypedDict(TypedDict):
    jobs: NotRequired[LpdMessageTypedDict]
    long_state: NotRequired[str]
    lpd_message: NotRequired[LpdMessageTypedDict]
    printer: NotRequired[str]
    raw: NotRequired[str]
    short_state: NotRequired[str]
    text: NotRequired[str]


class Lpd(BaseModel):
    jobs: Optional[LpdMessage] = None

    long_state: Optional[str] = None

    lpd_message: Optional[LpdMessage] = None

    printer: Optional[str] = None

    raw: Optional[str] = None

    short_state: Optional[str] = None

    text: Optional[str] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .pcanywhere_status import PcAnywhereStatus, PcAnywhereStatusTypedDict
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class PcAnywhereTypedDict(TypedDict):
    name: NotRequired[str]
    r"""Workstation Name, with padding bytes removed"""
    nr: NotRequired[str]
    r"""Full 'NR' query response"""
    status: NotRequired[PcAnywhereStatusTypedDict]


class PcAnywhere(BaseModel):
    name: Optional[str] = None
    r"""Workstation Name, with padding bytes removed"""

    nr: Optional[str] = None
    r"""Full 'NR' query response"""

    status: Optional[PcAnywhereStatus] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class CoapTypedDict(TypedDict):
    code: NotRequired[str]
    message_id: NotRequired[int]
    message_type: NotRequired[str]
    payload: NotRequired[str]
    token: NotRequired[str]
    version: NotRequired[int]


class Coap(BaseModel):
    code: Optional[str] = None

    message_id: Optional[int] = None

    message_type: Optional[str] = None

    payload: Optional[str] = None

    token: Optional[str] = None

    version: Optional[int] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class ElasticSearchResultsNodeInfoNodesNodeDataOSTypedDict(TypedDict):
    allocated_proc: NotRequired[int]
    arch: NotRequired[str]
    available_proc: NotRequired[int]
    name: NotRequired[str]
    pretty_name: NotRequired[str]
    refresh_interval_ms: NotRequired[int]
    version: NotRequired[str]


class ElasticSearchResultsNodeInfoNodesNodeDataOS(BaseModel):
    allocated_proc: Optional[int] = None

    arch: Optional[str] = None

    available_proc: Optional[int] = None

    name: Optional[str] = None

    pretty_name: Optional[str] = None

    refresh_interval_ms: Optional[int] = None

    version: Optional[str] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .evidence import Evidence, EvidenceTypedDict
from censys_platform.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
from enum import Enum
from pydantic import model_serializer
from typing import List, Optional
from typing_extensions import NotRequired, TypedDict


class LabelSource(str, Enum):
    UNKNOWN = ""
    CENSYS = "censys"
    RECOG = "recog"
    WAPPALYZER = "wappalyzer"
    THIRD_PARTY = "third_party"


class LabelTypedDict(TypedDict):
    confidence: NotRequired[float]
    evidence: NotRequired[Nullable[List[EvidenceTypedDict]]]
    source: NotRequired[LabelSource]
    value: NotRequired[str]


class Label(BaseModel):
    confidence: Optional[float] = None

    evidence: OptionalNullable[List[Evidence]] = UNSET

    source: Optional[LabelSource] = None

    value: Optional[str] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = ["confidence", "evidence", "source", "value"]
        nullable_fields = ["evidence"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .pixelformat import PixelFormat, PixelFormatTypedDict
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class DesktopInfoTypedDict(TypedDict):
    height: NotRequired[int]
    name_len: NotRequired[int]
    pixel_format: NotRequired[PixelFormatTypedDict]
    width: NotRequired[int]


class DesktopInfo(BaseModel):
    height: Optional[int] = None

    name_len: Optional[int] = None

    pixel_format: Optional[PixelFormat] = None

    width: Optional[int] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .cvss import Cvss, CvssTypedDict
from .cvssv4 import CVSSv4, CVSSv4TypedDict
from .epss import Epss, EpssTypedDict
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class MetricsTypedDict(TypedDict):
    cvss_v30: NotRequired[CvssTypedDict]
    cvss_v31: NotRequired[CvssTypedDict]
    cvss_v40: NotRequired[CVSSv4TypedDict]
    epss: NotRequired[EpssTypedDict]


class Metrics(BaseModel):
    cvss_v30: Optional[Cvss] = None

    cvss_v31: Optional[Cvss] = None

    cvss_v40: Optional[CVSSv4] = None

    epss: Optional[Epss] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class OpenDirectoryFileTypedDict(TypedDict):
    extension: NotRequired[str]
    last_modified: NotRequired[str]
    name: NotRequired[str]
    path: NotRequired[str]
    size: NotRequired[int]
    suspicious_score: NotRequired[float]
    type: NotRequired[str]


class OpenDirectoryFile(BaseModel):
    extension: Optional[str] = None

    last_modified: Optional[str] = None

    name: Optional[str] = None

    path: Optional[str] = None

    size: Optional[int] = None

    suspicious_score: Optional[float] = None

    type: Optional[str] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class PrometheusResponseActiveTargetLabelsTypedDict(TypedDict):
    instance: NotRequired[str]
    r"""Instance after relabelling has occurred."""
    job: NotRequired[str]
    r"""Job of target after relabelling has occurred."""


class PrometheusResponseActiveTargetLabels(BaseModel):
    instance: Optional[str] = None
    r"""Instance after relabelling has occurred."""

    job: Optional[str] = None
    r"""Job of target after relabelling has occurred."""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .elasticsearch_resultsnodeinfo_nodes_nodedata_nodesettings_node import (
    ElasticSearchResultsNodeInfoNodesNodeDataNodeSettingsNode,
    ElasticSearchResultsNodeInfoNodesNodeDataNodeSettingsNodeTypedDict,
)
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class ElasticSearchResultsNodeInfoNodesNodeDataNodeSettingsTypedDict(TypedDict):
    cluster_name: NotRequired[str]
    node: NotRequired[
        ElasticSearchResultsNodeInfoNodesNodeDataNodeSettingsNodeTypedDict
    ]


class ElasticSearchResultsNodeInfoNodesNodeDataNodeSettings(BaseModel):
    cluster_name: Optional[str] = None

    node: Optional[ElasticSearchResultsNodeInfoNodesNodeDataNodeSettingsNode] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .assetcertificatelistinputbody import (
    AssetCertificateListInputBody,
    AssetCertificateListInputBodyTypedDict,
)
from .responseenvelopelistcertificateasset import (
    ResponseEnvelopeListCertificateAsset,
    ResponseEnvelopeListCertificateAssetTypedDict,
)
from censys_platform.types import BaseModel
from censys_platform.utils import FieldMetadata, QueryParamMetadata, RequestMetadata
from typing import Dict, List, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class V3GlobaldataAssetCertificateListPostGlobalsTypedDict(TypedDict):
    organization_id: NotRequired[str]


class V3GlobaldataAssetCertificateListPostGlobals(BaseModel):
    organization_id: Annotated[
        Optional[str],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = None


class V3GlobaldataAssetCertificateListPostRequestTypedDict(TypedDict):
    asset_certificate_list_input_body: AssetCertificateListInputBodyTypedDict
    organization_id: NotRequired[str]
    r"""The ID of a Censys organization to associate the request with. If omitted, the request will be processed using the authenticated user's free wallet where applicable. See the [Getting Started docs](https://docs.censys.com/reference/get-started#step-3-find-and-use-your-organization-id-optional) for more information."""


class V3GlobaldataAssetCertificateListPostRequest(BaseModel):
    asset_certificate_list_input_body: Annotated[
        AssetCertificateListInputBody,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]

    organization_id: Annotated[
        Optional[str],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=False)),
    ] = None
    r"""The ID of a Censys organization to associate the request with. If omitted, the request will be processed using the authenticated user's free wallet where applicable. See the [Getting Started docs](https://docs.censys.com/reference/get-started#step-3-find-and-use-your-organization-id-optional) for more information."""


class V3GlobaldataAssetCertificateListPostResponseTypedDict(TypedDict):
    headers: Dict[str, List[str]]
    result: ResponseEnvelopeListCertificateAssetTypedDict


class V3GlobaldataAssetCertificateListPostResponse(BaseModel):
    headers: Dict[str, List[str]]

    result: ResponseEnvelopeListCertificateAsset



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class RdpEmbeddedRSACertTypedDict(TypedDict):
    key_length: NotRequired[int]
    magic: NotRequired[int]
    max_bytes_datalen: NotRequired[int]
    modulus: NotRequired[str]
    modulus_bitlen: NotRequired[int]
    public_exponent: NotRequired[int]
    signature: NotRequired[str]


class RdpEmbeddedRSACert(BaseModel):
    key_length: Optional[int] = None

    magic: Optional[int] = None

    max_bytes_datalen: Optional[int] = None

    modulus: Optional[str] = None

    modulus_bitlen: Optional[int] = None

    public_exponent: Optional[int] = None

    signature: Optional[str] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class ZeromqHandshakeTypedDict(TypedDict):
    raw: NotRequired[str]
    ready: NotRequired[bool]
    socket_type: NotRequired[str]


class ZeromqHandshake(BaseModel):
    raw: Optional[str] = None

    ready: Optional[bool] = None

    socket_type: Optional[str] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class SmbHeaderLogTypedDict(TypedDict):
    command: NotRequired[int]
    credits: NotRequired[int]
    flags: NotRequired[int]
    protocol_id: NotRequired[str]
    status: NotRequired[int]


class SmbHeaderLog(BaseModel):
    command: Optional[int] = None

    credits: Optional[int] = None

    flags: Optional[int] = None

    protocol_id: Optional[str] = None

    status: Optional[int] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from enum import Enum
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class KEVSource(str, Enum):
    r"""The source checked to determine whether the CVE is in the KEV catalog."""

    UNKNOWN = ""
    CISA = "cisa"
    THIRD_PARTY = "third_party"


class KevTypedDict(TypedDict):
    date_added: NotRequired[str]
    r"""The date the vulnerability was added to the KEV catalog."""
    date_due: NotRequired[str]
    r"""Per CISA’s Binding Operation Directive 22-01, the date all federal civilian executive branch (FCEB) agencies are required to remediate vulnerabilities in the KEV catalog."""
    source: NotRequired[KEVSource]
    r"""The source checked to determine whether the CVE is in the KEV catalog."""


class Kev(BaseModel):
    date_added: Optional[str] = None
    r"""The date the vulnerability was added to the KEV catalog."""

    date_due: Optional[str] = None
    r"""Per CISA’s Binding Operation Directive 22-01, the date all federal civilian executive branch (FCEB) agencies are required to remediate vulnerabilities in the KEV catalog."""

    source: Optional[KEVSource] = None
    r"""The source checked to determine whether the CVE is in the KEV catalog."""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .snmp_engine import SnmpEngine, SnmpEngineTypedDict
from .snmp_interfaces import SnmpInterfaces, SnmpInterfacesTypedDict
from .snmp_physical import SnmpPhysical, SnmpPhysicalTypedDict
from .snmp_system import SnmpSystem, SnmpSystemTypedDict
from censys_platform.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
from pydantic import model_serializer
from typing import List, Optional
from typing_extensions import NotRequired, TypedDict


class SnmpTypedDict(TypedDict):
    engine: NotRequired[SnmpEngineTypedDict]
    oid_interfaces: NotRequired[SnmpInterfacesTypedDict]
    oid_physical: NotRequired[SnmpPhysicalTypedDict]
    oid_system: NotRequired[SnmpSystemTypedDict]
    versions: NotRequired[Nullable[List[str]]]


class Snmp(BaseModel):
    engine: Optional[SnmpEngine] = None

    oid_interfaces: Optional[SnmpInterfaces] = None

    oid_physical: Optional[SnmpPhysical] = None

    oid_system: Optional[SnmpSystem] = None

    versions: OptionalNullable[List[str]] = UNSET

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = [
            "engine",
            "oid_interfaces",
            "oid_physical",
            "oid_system",
            "versions",
        ]
        nullable_fields = ["versions"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .valuecountsresponse import ValueCountsResponse, ValueCountsResponseTypedDict
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class ResponseEnvelopeValueCountsResponseTypedDict(TypedDict):
    result: NotRequired[ValueCountsResponseTypedDict]


class ResponseEnvelopeValueCountsResponse(BaseModel):
    result: Optional[ValueCountsResponse] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class WorkerTypedDict(TypedDict):
    client_id: NotRequired[str]
    fd: NotRequired[str]
    functions: NotRequired[str]
    ip: NotRequired[str]


class Worker(BaseModel):
    client_id: Optional[str] = None

    fd: Optional[str] = None

    functions: Optional[str] = None

    ip: Optional[str] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from enum import Enum
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class Reason(str, Enum):
    r"""An enumerated value indicating the issuer-supplied reason for the revocation."""

    UNKNOWN = ""
    UNSPECIFIED = "unspecified"
    KEY_COMPROMISE = "key_compromise"
    CA_COMPROMISE = "ca_compromise"
    AFFILIATION_CHANGED = "affiliation_changed"
    SUPERSEDED = "superseded"
    CESSATION_OF_OPERATION = "cessation_of_operation"
    CERTIFICATE_HOLD = "certificate_hold"
    REMOVE_FROM_CRL = "remove_from_crl"
    PRIVILEGE_WITHDRAWN = "privilege_withdrawn"
    AA_COMPROMISE = "aa_compromise"


class CertificateRevocationRevocationInfoTypedDict(TypedDict):
    next_update: NotRequired[str]
    reason: NotRequired[Reason]
    r"""An enumerated value indicating the issuer-supplied reason for the revocation."""
    revocation_time: NotRequired[str]
    r"""The issuer-supplied timestamp indicating when the certificate was revoked."""
    revoked: NotRequired[bool]
    r"""Whether the certificate has been revoked before its expiry date by the issuer."""


class CertificateRevocationRevocationInfo(BaseModel):
    next_update: Optional[str] = None

    reason: Optional[Reason] = None
    r"""An enumerated value indicating the issuer-supplied reason for the revocation."""

    revocation_time: Optional[str] = None
    r"""The issuer-supplied timestamp indicating when the certificate was revoked."""

    revoked: Optional[bool] = None
    r"""Whether the certificate has been revoked before its expiry date by the issuer."""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .rippleclioresults import RippleClioResults, RippleClioResultsTypedDict
from .rippledpublicresults import RippledPublicResults, RippledPublicResultsTypedDict
from .ripplepeerresults import RipplePeerResults, RipplePeerResultsTypedDict
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class RippleTypedDict(TypedDict):
    ripple_clio: NotRequired[RippleClioResultsTypedDict]
    rippled_peer: NotRequired[RipplePeerResultsTypedDict]
    rippled_public: NotRequired[RippledPublicResultsTypedDict]


class Ripple(BaseModel):
    ripple_clio: Optional[RippleClioResults] = None

    rippled_peer: Optional[RipplePeerResults] = None

    rippled_public: Optional[RippledPublicResults] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class SmbSmbVersionsTypedDict(TypedDict):
    major: NotRequired[int]
    r"""Major version"""
    minor: NotRequired[int]
    r"""Minor version"""
    revision: NotRequired[int]
    r"""Protocol Revision"""
    version_string: NotRequired[str]
    r"""Full SMB Version String"""


class SmbSmbVersions(BaseModel):
    major: Optional[int] = None
    r"""Major version"""

    minor: Optional[int] = None
    r"""Minor version"""

    revision: Optional[int] = None
    r"""Protocol Revision"""

    version_string: Optional[str] = None
    r"""Full SMB Version String"""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class IvantiAvalancheTypedDict(TypedDict):
    body: NotRequired[str]
    status_code: NotRequired[int]
    version: NotRequired[str]


class IvantiAvalanche(BaseModel):
    body: Optional[str] = None

    status_code: Optional[int] = None

    version: Optional[str] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class StatusTypedDict(TypedDict):
    available_workers: NotRequired[int]
    function: NotRequired[str]
    running: NotRequired[int]
    total: NotRequired[int]


class Status(BaseModel):
    available_workers: Optional[int] = None

    function: Optional[str] = None

    running: Optional[int] = None

    total: Optional[int] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class KrpcTypedDict(TypedDict):
    ping_response_id: NotRequired[str]


class Krpc(BaseModel):
    ping_response_id: Optional[str] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .kubernetes_endpoint import KubernetesEndpoint, KubernetesEndpointTypedDict
from .kubernetes_node import KubernetesNode, KubernetesNodeTypedDict
from .kubernetes_role import KubernetesRole, KubernetesRoleTypedDict
from .kubernetes_versioninfo import (
    KubernetesVersionInfo,
    KubernetesVersionInfoTypedDict,
)
from censys_platform.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
from pydantic import model_serializer
from typing import List, Optional
from typing_extensions import NotRequired, TypedDict


class KubernetesTypedDict(TypedDict):
    endpoints: NotRequired[Nullable[List[KubernetesEndpointTypedDict]]]
    kubernetes_dashboard_found: NotRequired[bool]
    r"""True if the dashboard is running and accessible"""
    nodes: NotRequired[Nullable[List[KubernetesNodeTypedDict]]]
    pod_names: NotRequired[Nullable[List[str]]]
    roles: NotRequired[Nullable[List[KubernetesRoleTypedDict]]]
    version_info: NotRequired[KubernetesVersionInfoTypedDict]


class Kubernetes(BaseModel):
    endpoints: OptionalNullable[List[KubernetesEndpoint]] = UNSET

    kubernetes_dashboard_found: Optional[bool] = None
    r"""True if the dashboard is running and accessible"""

    nodes: OptionalNullable[List[KubernetesNode]] = UNSET

    pod_names: OptionalNullable[List[str]] = UNSET

    roles: OptionalNullable[List[KubernetesRole]] = UNSET

    version_info: Optional[KubernetesVersionInfo] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = [
            "endpoints",
            "kubernetes_dashboard_found",
            "nodes",
            "pod_names",
            "roles",
            "version_info",
        ]
        nullable_fields = ["endpoints", "nodes", "pod_names", "roles"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .hostobservationresponse import (
    HostObservationResponse,
    HostObservationResponseTypedDict,
)
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class ResponseEnvelopeHostObservationResponseTypedDict(TypedDict):
    result: NotRequired[HostObservationResponseTypedDict]


class ResponseEnvelopeHostObservationResponse(BaseModel):
    result: Optional[HostObservationResponse] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class SnmpSystemServicesTypedDict(TypedDict):
    layer_1: NotRequired[bool]
    r"""Physical (e.g. repeaters)"""
    layer_2: NotRequired[bool]
    r"""Datalink/subnetwork (e.g. bridges)"""
    layer_3: NotRequired[bool]
    r"""Internet (e.g. IP gateways)"""
    layer_4: NotRequired[bool]
    r"""End-to-end (e.g. IP hosts)"""
    layer_5: NotRequired[bool]
    r"""OSI layer 5"""
    layer_6: NotRequired[bool]
    r"""OSI layer 6"""
    layer_7: NotRequired[bool]
    r"""Applications (e.g. mail relays)"""


class SnmpSystemServices(BaseModel):
    layer_1: Optional[bool] = None
    r"""Physical (e.g. repeaters)"""

    layer_2: Optional[bool] = None
    r"""Datalink/subnetwork (e.g. bridges)"""

    layer_3: Optional[bool] = None
    r"""Internet (e.g. IP gateways)"""

    layer_4: Optional[bool] = None
    r"""End-to-end (e.g. IP hosts)"""

    layer_5: Optional[bool] = None
    r"""OSI layer 5"""

    layer_6: Optional[bool] = None
    r"""OSI layer 6"""

    layer_7: Optional[bool] = None
    r"""Applications (e.g. mail relays)"""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .responseenvelopewebpropertyasset import (
    ResponseEnvelopeWebpropertyAsset,
    ResponseEnvelopeWebpropertyAssetTypedDict,
)
from censys_platform.types import BaseModel
from censys_platform.utils import FieldMetadata, PathParamMetadata, QueryParamMetadata
from datetime import datetime
from typing import Dict, List, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class V3GlobaldataAssetWebpropertyGlobalsTypedDict(TypedDict):
    organization_id: NotRequired[str]


class V3GlobaldataAssetWebpropertyGlobals(BaseModel):
    organization_id: Annotated[
        Optional[str],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = None


class V3GlobaldataAssetWebpropertyRequestTypedDict(TypedDict):
    webproperty_id: str
    r"""A web property identifier."""
    organization_id: NotRequired[str]
    r"""The ID of a Censys organization to associate the request with. If omitted, the request will be processed using the authenticated user's free wallet where applicable. See the [Getting Started docs](https://docs.censys.com/reference/get-started#step-3-find-and-use-your-organization-id-optional) for more information."""
    at_time: NotRequired[datetime]
    r"""RFC3339 Timestamp to view a webproperty at a specific point in time. Must be a valid RFC3339 string. Ensure that you suffix the date with T00:00:00Z or a specific time"""


class V3GlobaldataAssetWebpropertyRequest(BaseModel):
    webproperty_id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]
    r"""A web property identifier."""

    organization_id: Annotated[
        Optional[str],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=False)),
    ] = None
    r"""The ID of a Censys organization to associate the request with. If omitted, the request will be processed using the authenticated user's free wallet where applicable. See the [Getting Started docs](https://docs.censys.com/reference/get-started#step-3-find-and-use-your-organization-id-optional) for more information."""

    at_time: Annotated[
        Optional[datetime],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=False)),
    ] = None
    r"""RFC3339 Timestamp to view a webproperty at a specific point in time. Must be a valid RFC3339 string. Ensure that you suffix the date with T00:00:00Z or a specific time"""


class V3GlobaldataAssetWebpropertyResponseTypedDict(TypedDict):
    headers: Dict[str, List[str]]
    result: ResponseEnvelopeWebpropertyAssetTypedDict


class V3GlobaldataAssetWebpropertyResponse(BaseModel):
    headers: Dict[str, List[str]]

    result: ResponseEnvelopeWebpropertyAsset



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .ipmi_capabilities import IpmiCapabilities, IpmiCapabilitiesTypedDict
from .ipmi_commandpayload import IpmiCommandPayload, IpmiCommandPayloadTypedDict
from .ipmi_rmcpheader import IpmiRMCPHeader, IpmiRMCPHeaderTypedDict
from .ipmi_sessionheader import IpmiSessionHeader, IpmiSessionHeaderTypedDict
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class IpmiTypedDict(TypedDict):
    capabilities: NotRequired[IpmiCapabilitiesTypedDict]
    command_payload: NotRequired[IpmiCommandPayloadTypedDict]
    raw: NotRequired[str]
    r"""The raw data returned by the server"""
    rmcp_header: NotRequired[IpmiRMCPHeaderTypedDict]
    session_header: NotRequired[IpmiSessionHeaderTypedDict]


class Ipmi(BaseModel):
    capabilities: Optional[IpmiCapabilities] = None

    command_payload: Optional[IpmiCommandPayload] = None

    raw: Optional[str] = None
    r"""The raw data returned by the server"""

    rmcp_header: Optional[IpmiRMCPHeader] = None

    session_header: Optional[IpmiSessionHeader] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .dhcpdiscover_deviceinfo import (
    DhcpdiscoverDeviceInfo,
    DhcpdiscoverDeviceInfoTypedDict,
)
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class DhcpdiscoverResponseParamsTypedDict(TypedDict):
    device_info: NotRequired[DhcpdiscoverDeviceInfoTypedDict]


class DhcpdiscoverResponseParams(BaseModel):
    device_info: Optional[DhcpdiscoverDeviceInfo] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class CweTypedDict(TypedDict):
    entry: NotRequired[str]
    r"""A unique identifier associated with a class of a software or hardware weakness."""


class Cwe(BaseModel):
    entry: Optional[str] = None
    r"""A unique identifier associated with a class of a software or hardware weakness."""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .webproperty import Webproperty, WebpropertyTypedDict
from censys_platform.types import BaseModel
from typing import Any, Dict
from typing_extensions import TypedDict


class WebpropertyAssetTypedDict(TypedDict):
    extensions: Dict[str, Any]
    resource: WebpropertyTypedDict


class WebpropertyAsset(BaseModel):
    extensions: Dict[str, Any]

    resource: Webproperty



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Dict, Optional
from typing_extensions import NotRequired, TypedDict


class MemcachedTypedDict(TypedDict):
    ascii_binding_protocol_enabled: NotRequired[bool]
    r"""Whether server responds to a handshake using the ASCII wire format of the protocol."""
    binary_binding_protocol_enabled: NotRequired[bool]
    r"""Whether server responds to a handshake using the binary wire format of the protocol."""
    responds_to_udp: NotRequired[bool]
    r"""Whether the server on the UDP port with the same number responds to a handshake using the ASCII wire format of the protocol."""
    stats: NotRequired[Dict[str, str]]
    r"""Server information returned in response to the stats command, as a set of key:value pairs."""
    version: NotRequired[str]
    r"""The Memcached version indicated in the server's response."""


class Memcached(BaseModel):
    ascii_binding_protocol_enabled: Optional[bool] = None
    r"""Whether server responds to a handshake using the ASCII wire format of the protocol."""

    binary_binding_protocol_enabled: Optional[bool] = None
    r"""Whether server responds to a handshake using the binary wire format of the protocol."""

    responds_to_udp: Optional[bool] = None
    r"""Whether the server on the UDP port with the same number responds to a handshake using the ASCII wire format of the protocol."""

    stats: Optional[Dict[str, str]] = None
    r"""Server information returned in response to the stats command, as a set of key:value pairs."""

    version: Optional[str] = None
    r"""The Memcached version indicated in the server's response."""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .responseenvelopehostobservationresponse import (
    ResponseEnvelopeHostObservationResponse,
    ResponseEnvelopeHostObservationResponseTypedDict,
)
from censys_platform.types import BaseModel
from censys_platform.utils import FieldMetadata, PathParamMetadata, QueryParamMetadata
from typing import Dict, List, Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class V3ThreathuntingGetHostObservationsWithCertificateGlobalsTypedDict(TypedDict):
    organization_id: NotRequired[str]


class V3ThreathuntingGetHostObservationsWithCertificateGlobals(BaseModel):
    organization_id: Annotated[
        Optional[str],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=True)),
    ] = None


class V3ThreathuntingGetHostObservationsWithCertificateRequestTypedDict(TypedDict):
    certificate_id: str
    r"""SHA-256 hash of the certificate"""
    organization_id: NotRequired[str]
    r"""The ID of a Censys organization to associate the request with. See the [Getting Started docs](https://docs.censys.com/reference/get-started#step-3-find-and-use-your-organization-id-optional) for more information."""
    start_time: NotRequired[str]
    r"""Only show ranges ending at or after this time (ISO 8601)"""
    end_time: NotRequired[str]
    r"""Only show ranges starting at or before this time (ISO 8601)"""
    port: NotRequired[int]
    r"""The port to filter by"""
    protocol: NotRequired[str]
    r"""The transport protocol to filter by"""
    page_token: NotRequired[str]
    r"""Pagination token from previous response to retrieve next page of results"""
    page_size: NotRequired[int]
    r"""Number of results per page. Maximum 100, defaults to 100 if not specified"""


class V3ThreathuntingGetHostObservationsWithCertificateRequest(BaseModel):
    certificate_id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]
    r"""SHA-256 hash of the certificate"""

    organization_id: Annotated[
        Optional[str],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=False)),
    ] = None
    r"""The ID of a Censys organization to associate the request with. See the [Getting Started docs](https://docs.censys.com/reference/get-started#step-3-find-and-use-your-organization-id-optional) for more information."""

    start_time: Annotated[
        Optional[str],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=False)),
    ] = None
    r"""Only show ranges ending at or after this time (ISO 8601)"""

    end_time: Annotated[
        Optional[str],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=False)),
    ] = None
    r"""Only show ranges starting at or before this time (ISO 8601)"""

    port: Annotated[
        Optional[int],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=False)),
    ] = None
    r"""The port to filter by"""

    protocol: Annotated[
        Optional[str],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=False)),
    ] = None
    r"""The transport protocol to filter by"""

    page_token: Annotated[
        Optional[str],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=False)),
    ] = None
    r"""Pagination token from previous response to retrieve next page of results"""

    page_size: Annotated[
        Optional[int],
        FieldMetadata(query=QueryParamMetadata(style="form", explode=False)),
    ] = None
    r"""Number of results per page. Maximum 100, defaults to 100 if not specified"""


class V3ThreathuntingGetHostObservationsWithCertificateResponseTypedDict(TypedDict):
    headers: Dict[str, List[str]]
    result: ResponseEnvelopeHostObservationResponseTypedDict


class V3ThreathuntingGetHostObservationsWithCertificateResponse(BaseModel):
    headers: Dict[str, List[str]]

    result: ResponseEnvelopeHostObservationResponse



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .l2tp_attributevalues import L2TpAttributeValues, L2TpAttributeValuesTypedDict
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class L2TpStopCcnTypedDict(TypedDict):
    attribute_values: NotRequired[L2TpAttributeValuesTypedDict]


class L2TpStopCcn(BaseModel):
    attribute_values: Optional[L2TpAttributeValues] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class AutonomousSystemTypedDict(TypedDict):
    asn: NotRequired[int]
    r"""The ASN (autonomous system number) of the host's autonomous system."""
    bgp_prefix: NotRequired[str]
    r"""The autonomous system's CIDR."""
    country_code: NotRequired[str]
    r"""The autonomous system's two-letter ISO 3166-1 alpha-2 country code (US, CN, GB, RU, ...)."""
    description: NotRequired[str]
    r"""Brief description of the autonomous system."""
    name: NotRequired[str]
    r"""The friendly name of the autonomous system."""
    organization: NotRequired[str]
    r"""The name of the organization managning the autonomous system."""


class AutonomousSystem(BaseModel):
    asn: Optional[int] = None
    r"""The ASN (autonomous system number) of the host's autonomous system."""

    bgp_prefix: Optional[str] = None
    r"""The autonomous system's CIDR."""

    country_code: Optional[str] = None
    r"""The autonomous system's two-letter ISO 3166-1 alpha-2 country code (US, CN, GB, RU, ...)."""

    description: Optional[str] = None
    r"""Brief description of the autonomous system."""

    name: Optional[str] = None
    r"""The friendly name of the autonomous system."""

    organization: Optional[str] = None
    r"""The name of the organization managning the autonomous system."""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .elasticsearch_resultsnodeinfo_nodes_nodedata_jvm import (
    ElasticSearchResultsNodeInfoNodesNodeDataJVM,
    ElasticSearchResultsNodeInfoNodesNodeDataJVMTypedDict,
)
from .elasticsearch_resultsnodeinfo_nodes_nodedata_modules import (
    ElasticSearchResultsNodeInfoNodesNodeDataModules,
    ElasticSearchResultsNodeInfoNodesNodeDataModulesTypedDict,
)
from .elasticsearch_resultsnodeinfo_nodes_nodedata_nodesettings import (
    ElasticSearchResultsNodeInfoNodesNodeDataNodeSettings,
    ElasticSearchResultsNodeInfoNodesNodeDataNodeSettingsTypedDict,
)
from .elasticsearch_resultsnodeinfo_nodes_nodedata_os import (
    ElasticSearchResultsNodeInfoNodesNodeDataOS,
    ElasticSearchResultsNodeInfoNodesNodeDataOSTypedDict,
)
from .elasticsearch_resultsnodeinfo_nodes_nodedata_threadpool import (
    ElasticSearchResultsNodeInfoNodesNodeDataThreadPool,
    ElasticSearchResultsNodeInfoNodesNodeDataThreadPoolTypedDict,
)
from censys_platform.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
from pydantic import model_serializer
from typing import List, Optional
from typing_extensions import NotRequired, TypedDict


class ElasticSearchResultsNodeInfoNodesNodeDataTypedDict(TypedDict):
    build_flavor: NotRequired[str]
    build_hash: NotRequired[str]
    build_type: NotRequired[str]
    host: NotRequired[str]
    ingest_processors: NotRequired[Nullable[List[str]]]
    ip: NotRequired[str]
    ip_raw: NotRequired[str]
    jvm: NotRequired[ElasticSearchResultsNodeInfoNodesNodeDataJVMTypedDict]
    modules: NotRequired[
        Nullable[List[ElasticSearchResultsNodeInfoNodesNodeDataModulesTypedDict]]
    ]
    name: NotRequired[str]
    os: NotRequired[ElasticSearchResultsNodeInfoNodesNodeDataOSTypedDict]
    roles: NotRequired[Nullable[List[str]]]
    settings: NotRequired[
        ElasticSearchResultsNodeInfoNodesNodeDataNodeSettingsTypedDict
    ]
    thread_pool_list: NotRequired[
        Nullable[List[ElasticSearchResultsNodeInfoNodesNodeDataThreadPoolTypedDict]]
    ]
    total_indexing_buffer: NotRequired[int]
    version: NotRequired[str]


class ElasticSearchResultsNodeInfoNodesNodeData(BaseModel):
    build_flavor: Optional[str] = None

    build_hash: Optional[str] = None

    build_type: Optional[str] = None

    host: Optional[str] = None

    ingest_processors: OptionalNullable[List[str]] = UNSET

    ip: Optional[str] = None

    ip_raw: Optional[str] = None

    jvm: Optional[ElasticSearchResultsNodeInfoNodesNodeDataJVM] = None

    modules: OptionalNullable[
        List[ElasticSearchResultsNodeInfoNodesNodeDataModules]
    ] = UNSET

    name: Optional[str] = None

    os: Optional[ElasticSearchResultsNodeInfoNodesNodeDataOS] = None

    roles: OptionalNullable[List[str]] = UNSET

    settings: Optional[ElasticSearchResultsNodeInfoNodesNodeDataNodeSettings] = None

    thread_pool_list: OptionalNullable[
        List[ElasticSearchResultsNodeInfoNodesNodeDataThreadPool]
    ] = UNSET

    total_indexing_buffer: Optional[int] = None

    version: Optional[str] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = [
            "build_flavor",
            "build_hash",
            "build_type",
            "host",
            "ingest_processors",
            "ip",
            "ip_raw",
            "jvm",
            "modules",
            "name",
            "os",
            "roles",
            "settings",
            "thread_pool_list",
            "total_indexing_buffer",
            "version",
        ]
        nullable_fields = ["ingest_processors", "modules", "roles", "thread_pool_list"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .ntp_ntpheader import NTPNTPHeader, NTPNTPHeaderTypedDict
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class NtpTypedDict(TypedDict):
    get_time_header: NotRequired[NTPNTPHeaderTypedDict]


class Ntp(BaseModel):
    get_time_header: Optional[NTPNTPHeader] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class FtpTypedDict(TypedDict):
    auth_ssl_response: NotRequired[str]
    auth_tls_response: NotRequired[str]
    implicit_tls: NotRequired[bool]
    status_code: NotRequired[int]
    status_meaning: NotRequired[str]


class Ftp(BaseModel):
    auth_ssl_response: Optional[str] = None

    auth_tls_response: Optional[str] = None

    implicit_tls: Optional[bool] = None

    status_code: Optional[int] = None

    status_meaning: Optional[str] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .rdp_certificateinfo import RdpCertificateInfo, RdpCertificateInfoTypedDict
from .rdp_connectresponse import RdpConnectResponse, RdpConnectResponseTypedDict
from .rdp_protocolflags import RdpProtocolFlags, RdpProtocolFlagsTypedDict
from .rdp_securityprotocol import RdpSecurityProtocol, RdpSecurityProtocolTypedDict
from .rdp_version import RdpVersion, RdpVersionTypedDict
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class RdpTypedDict(TypedDict):
    certificate_info: NotRequired[RdpCertificateInfoTypedDict]
    connect_response: NotRequired[RdpConnectResponseTypedDict]
    protocol_flags: NotRequired[RdpProtocolFlagsTypedDict]
    selected_security_protocol: NotRequired[RdpSecurityProtocolTypedDict]
    version: NotRequired[RdpVersionTypedDict]
    x224_cc_pdu_dstref: NotRequired[int]
    x224_cc_pdu_srcref: NotRequired[int]


class Rdp(BaseModel):
    certificate_info: Optional[RdpCertificateInfo] = None

    connect_response: Optional[RdpConnectResponse] = None

    protocol_flags: Optional[RdpProtocolFlags] = None

    selected_security_protocol: Optional[RdpSecurityProtocol] = None

    version: Optional[RdpVersion] = None

    x224_cc_pdu_dstref: Optional[int] = None

    x224_cc_pdu_srcref: Optional[int] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .analyticscapabilities import AnalyticsCapabilities, AnalyticsCapabilitiesTypedDict
from .devicecapabilities import DeviceCapabilities, DeviceCapabilitiesTypedDict
from .deviceiocapabilities import DeviceIOCapabilities, DeviceIOCapabilitiesTypedDict
from .eventscapabilities import EventsCapabilities, EventsCapabilitiesTypedDict
from .imagecapabilities import ImageCapabilities, ImageCapabilitiesTypedDict
from .mediacapabilities import MediaCapabilities, MediaCapabilitiesTypedDict
from .pantiltzoomcapabilities import (
    PanTiltZoomCapabilities,
    PanTiltZoomCapabilitiesTypedDict,
)
from .recordingcapabilities import RecordingCapabilities, RecordingCapabilitiesTypedDict
from .replaycapabilities import ReplayCapabilities, ReplayCapabilitiesTypedDict
from .searchcapabilities import SearchCapabilities, SearchCapabilitiesTypedDict
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class CapabilitiesTypedDict(TypedDict):
    analytics: NotRequired[AnalyticsCapabilitiesTypedDict]
    device: NotRequired[DeviceCapabilitiesTypedDict]
    device_io: NotRequired[DeviceIOCapabilitiesTypedDict]
    events: NotRequired[EventsCapabilitiesTypedDict]
    image: NotRequired[ImageCapabilitiesTypedDict]
    media: NotRequired[MediaCapabilitiesTypedDict]
    pan_tilt_zoom: NotRequired[PanTiltZoomCapabilitiesTypedDict]
    recording: NotRequired[RecordingCapabilitiesTypedDict]
    replay: NotRequired[ReplayCapabilitiesTypedDict]
    search: NotRequired[SearchCapabilitiesTypedDict]


class Capabilities(BaseModel):
    analytics: Optional[AnalyticsCapabilities] = None

    device: Optional[DeviceCapabilities] = None

    device_io: Optional[DeviceIOCapabilities] = None

    events: Optional[EventsCapabilities] = None

    image: Optional[ImageCapabilities] = None

    media: Optional[MediaCapabilities] = None

    pan_tilt_zoom: Optional[PanTiltZoomCapabilities] = None

    recording: Optional[RecordingCapabilities] = None

    replay: Optional[ReplayCapabilities] = None

    search: Optional[SearchCapabilities] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .noticereference import NoticeReference, NoticeReferenceTypedDict
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class UserNoticeTypedDict(TypedDict):
    explicit_text: NotRequired[str]
    notice_reference: NotRequired[NoticeReferenceTypedDict]


class UserNotice(BaseModel):
    explicit_text: Optional[str] = None

    notice_reference: Optional[NoticeReference] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .elasticsearch_resultsnodeinfo_nodes_nodedata import (
    ElasticSearchResultsNodeInfoNodesNodeData,
    ElasticSearchResultsNodeInfoNodesNodeDataTypedDict,
)
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class ElasticSearchResultsNodeInfoNodesTypedDict(TypedDict):
    node_data: NotRequired[ElasticSearchResultsNodeInfoNodesNodeDataTypedDict]
    node_name: NotRequired[str]


class ElasticSearchResultsNodeInfoNodes(BaseModel):
    node_data: Optional[ElasticSearchResultsNodeInfoNodesNodeData] = None

    node_name: Optional[str] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class CoordinatesTypedDict(TypedDict):
    latitude: NotRequired[float]
    longitude: NotRequired[float]


class Coordinates(BaseModel):
    latitude: Optional[float] = None

    longitude: Optional[float] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .cobaltstrike_httpconfig import (
    CobaltStrikeHTTPConfig,
    CobaltStrikeHTTPConfigTypedDict,
)
from .cobaltstrike_postex import CobaltStrikePostEx, CobaltStrikePostExTypedDict
from censys_platform.types import BaseModel, Nullable
from typing import Dict, Optional
from typing_extensions import NotRequired, TypedDict


class CobaltStrikeConfigTypedDict(TypedDict):
    cookie_beacon: NotRequired[int]
    crypto_scheme: NotRequired[int]
    dns: NotRequired[bool]
    http_get: NotRequired[CobaltStrikeHTTPConfigTypedDict]
    http_post: NotRequired[CobaltStrikeHTTPConfigTypedDict]
    jitter: NotRequired[int]
    killdate: NotRequired[int]
    post_ex: NotRequired[CobaltStrikePostExTypedDict]
    public_key: NotRequired[str]
    sleep_time: NotRequired[int]
    ssl: NotRequired[bool]
    unknown_bytes: NotRequired[Dict[str, Nullable[str]]]
    unknown_int: NotRequired[Dict[str, int]]
    user_agent: NotRequired[str]
    watermark: NotRequired[int]


class CobaltStrikeConfig(BaseModel):
    cookie_beacon: Optional[int] = None

    crypto_scheme: Optional[int] = None

    dns: Optional[bool] = None

    http_get: Optional[CobaltStrikeHTTPConfig] = None

    http_post: Optional[CobaltStrikeHTTPConfig] = None

    jitter: Optional[int] = None

    killdate: Optional[int] = None

    post_ex: Optional[CobaltStrikePostEx] = None

    public_key: Optional[str] = None

    sleep_time: Optional[int] = None

    ssl: Optional[bool] = None

    unknown_bytes: Optional[Dict[str, Nullable[str]]] = None

    unknown_int: Optional[Dict[str, int]] = None

    user_agent: Optional[str] = None

    watermark: Optional[int] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class SmbSmbCapabilitiesTypedDict(TypedDict):
    smb_dfs_support: NotRequired[bool]
    r"""Server supports Distributed File System"""
    smb_directory_leasing_support: NotRequired[bool]
    r"""Server supports directory leasing"""
    smb_encryption_support: NotRequired[bool]
    r"""Server supports encryption"""
    smb_leasing_support: NotRequired[bool]
    r"""Server supports Leasing"""
    smb_multichan_support: NotRequired[bool]
    r"""Server supports multiple channels per session"""
    smb_multicredit_support: NotRequired[bool]
    r"""Server supports multi-credit operations"""
    smb_persistent_handle_support: NotRequired[bool]
    r"""Server supports persistent handles"""


class SmbSmbCapabilities(BaseModel):
    smb_dfs_support: Optional[bool] = None
    r"""Server supports Distributed File System"""

    smb_directory_leasing_support: Optional[bool] = None
    r"""Server supports directory leasing"""

    smb_encryption_support: Optional[bool] = None
    r"""Server supports encryption"""

    smb_leasing_support: Optional[bool] = None
    r"""Server supports Leasing"""

    smb_multichan_support: Optional[bool] = None
    r"""Server supports multiple channels per session"""

    smb_multicredit_support: Optional[bool] = None
    r"""Server supports multi-credit operations"""

    smb_persistent_handle_support: Optional[bool] = None
    r"""Server supports persistent handles"""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .l2tp_sccrp import L2TpSccrp, L2TpSccrpTypedDict
from .l2tp_stopccn import L2TpStopCcn, L2TpStopCcnTypedDict
from censys_platform.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
from pydantic import model_serializer
from typing import List, Optional
from typing_extensions import NotRequired, TypedDict


class L2TpTypedDict(TypedDict):
    hello_received: NotRequired[bool]
    ordered_messages_raw: NotRequired[Nullable[List[str]]]
    sccn_received: NotRequired[bool]
    sccrp: NotRequired[L2TpSccrpTypedDict]
    sccrp_received: NotRequired[bool]
    sccrq_received: NotRequired[bool]
    stop_sccn: NotRequired[L2TpStopCcnTypedDict]
    stop_sccn_received: NotRequired[bool]
    zlb_received: NotRequired[bool]


class L2Tp(BaseModel):
    hello_received: Optional[bool] = None

    ordered_messages_raw: OptionalNullable[List[str]] = UNSET

    sccn_received: Optional[bool] = None

    sccrp: Optional[L2TpSccrp] = None

    sccrp_received: Optional[bool] = None

    sccrq_received: Optional[bool] = None

    stop_sccn: Optional[L2TpStopCcn] = None

    stop_sccn_received: Optional[bool] = None

    zlb_received: Optional[bool] = None

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = [
            "hello_received",
            "ordered_messages_raw",
            "sccn_received",
            "sccrp",
            "sccrp_received",
            "sccrq_received",
            "stop_sccn",
            "stop_sccn_received",
            "zlb_received",
        ]
        nullable_fields = ["ordered_messages_raw"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class IpmiSessionHeaderAuthTypeTypedDict(TypedDict):
    name: NotRequired[str]
    r"""The raw value of the auth_type"""
    raw: NotRequired[int]
    r"""The raw value of the auth_type"""
    type: NotRequired[int]
    r"""Just the auth type (reserved bits omitted)"""


class IpmiSessionHeaderAuthType(BaseModel):
    name: Optional[str] = None
    r"""The raw value of the auth_type"""

    raw: Optional[int] = None
    r"""The raw value of the auth_type"""

    type: Optional[int] = None
    r"""Just the auth type (reserved bits omitted)"""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .tls_chain import TLSChain, TLSChainTypedDict
from .tls_versiondata import TLSVersionData, TLSVersionDataTypedDict
from censys_platform.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
from enum import Enum
from pydantic import model_serializer
from typing import List, Optional
from typing_extensions import NotRequired, TypedDict


class VersionSelected(str, Enum):
    r"""Certificate version v1(0), v2(1), v3(2)."""

    UNKNOWN = ""
    SS_LV_2 = "ss_lv_2"
    SS_LV_3 = "ss_lv_3"
    TLSV1_0 = "tlsv1_0"
    TLSV1_1 = "tlsv1_1"
    TLSV1_2 = "tlsv1_2"
    TLSV1_3 = "tlsv1_3"
    DTLSV1_0 = "dtlsv1_0"
    DTLSV1_2 = "dtlsv1_2"
    DTLSV1_3 = "dtlsv1_3"


class TLSTypedDict(TypedDict):
    cipher_selected: NotRequired[str]
    r"""Cipher suite chosen for the exchange."""
    fingerprint_sha256: NotRequired[str]
    r"""The SHA-256 digest of the entire raw certificate. Its unique identifier, which Censys uses to index certificates records."""
    ja3s: NotRequired[str]
    r"""The JA3S fingerprint for this service."""
    ja4s: NotRequired[str]
    presented_chain: NotRequired[Nullable[List[TLSChainTypedDict]]]
    r"""Certificate chain information."""
    version_selected: NotRequired[VersionSelected]
    r"""Certificate version v1(0), v2(1), v3(2)."""
    versions: NotRequired[Nullable[List[TLSVersionDataTypedDict]]]


class TLS(BaseModel):
    cipher_selected: Optional[str] = None
    r"""Cipher suite chosen for the exchange."""

    fingerprint_sha256: Optional[str] = None
    r"""The SHA-256 digest of the entire raw certificate. Its unique identifier, which Censys uses to index certificates records."""

    ja3s: Optional[str] = None
    r"""The JA3S fingerprint for this service."""

    ja4s: Optional[str] = None

    presented_chain: OptionalNullable[List[TLSChain]] = UNSET
    r"""Certificate chain information."""

    version_selected: Optional[VersionSelected] = None
    r"""Certificate version v1(0), v2(1), v3(2)."""

    versions: OptionalNullable[List[TLSVersionData]] = UNSET

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = [
            "cipher_selected",
            "fingerprint_sha256",
            "ja3s",
            "ja4s",
            "presented_chain",
            "version_selected",
            "versions",
        ]
        nullable_fields = ["presented_chain", "versions"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .elasticsearch_resultsnodeinfo_clustercombinedinfo_filesystem import (
    ElasticSearchResultsNodeInfoClusterCombinedInfoFilesystem,
    ElasticSearchResultsNodeInfoClusterCombinedInfoFilesystemTypedDict,
)
from .elasticsearch_resultsnodeinfo_clustercombinedinfo_indices import (
    ElasticSearchResultsNodeInfoClusterCombinedInfoIndices,
    ElasticSearchResultsNodeInfoClusterCombinedInfoIndicesTypedDict,
)
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class ElasticSearchResultsNodeInfoClusterCombinedInfoTypedDict(TypedDict):
    filesystem: NotRequired[
        ElasticSearchResultsNodeInfoClusterCombinedInfoFilesystemTypedDict
    ]
    indices: NotRequired[
        ElasticSearchResultsNodeInfoClusterCombinedInfoIndicesTypedDict
    ]
    name: NotRequired[str]
    status: NotRequired[str]
    timestamp: NotRequired[int]
    uuid: NotRequired[str]


class ElasticSearchResultsNodeInfoClusterCombinedInfo(BaseModel):
    filesystem: Optional[ElasticSearchResultsNodeInfoClusterCombinedInfoFilesystem] = (
        None
    )

    indices: Optional[ElasticSearchResultsNodeInfoClusterCombinedInfoIndices] = None

    name: Optional[str] = None

    status: Optional[str] = None

    timestamp: Optional[int] = None

    uuid: Optional[str] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class ExtensionTypedDict(TypedDict):
    critical: NotRequired[bool]
    id: NotRequired[str]
    value: NotRequired[str]


class Extension(BaseModel):
    critical: Optional[bool] = None

    id: Optional[str] = None

    value: Optional[str] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .rocketmq_clusterinfo import RocketmqClusterInfo, RocketmqClusterInfoTypedDict
from .rocketmq_topiclist import RocketmqTopicList, RocketmqTopicListTypedDict
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class RocketmqTypedDict(TypedDict):
    cluster_info: NotRequired[RocketmqClusterInfoTypedDict]
    topics: NotRequired[RocketmqTopicListTypedDict]
    version: NotRequired[str]


class Rocketmq(BaseModel):
    cluster_info: Optional[RocketmqClusterInfo] = None

    topics: Optional[RocketmqTopicList] = None

    version: Optional[str] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .murmurmessage_murmurheader import (
    MurmurMessageMurmurHeader,
    MurmurMessageMurmurHeaderTypedDict,
)
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class MurmurMessageTypedDict(TypedDict):
    body: NotRequired[str]
    header: NotRequired[MurmurMessageMurmurHeaderTypedDict]


class MurmurMessage(BaseModel):
    body: Optional[str] = None

    header: Optional[MurmurMessageMurmurHeader] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Dict, Optional
from typing_extensions import NotRequired, TypedDict


class PostgresTypedDict(TypedDict):
    protocol_error: NotRequired[Dict[str, str]]
    r"""The error received in response to a StartupMessage with an unexpected protocol version."""
    startup_error: NotRequired[Dict[str, str]]
    r"""The error received in response to a StartupMessage without providing the User field."""
    supported_versions: NotRequired[str]


class Postgres(BaseModel):
    protocol_error: Optional[Dict[str, str]] = None
    r"""The error received in response to a StartupMessage with an unexpected protocol version."""

    startup_error: Optional[Dict[str, str]] = None
    r"""The error received in response to a StartupMessage without providing the User field."""

    supported_versions: Optional[str] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .elasticsearch_errormessage import (
    ElasticSearchErrorMessage,
    ElasticSearchErrorMessageTypedDict,
)
from .elasticsearch_resultsnodeinfo import (
    ElasticSearchResultsNodeInfo,
    ElasticSearchResultsNodeInfoTypedDict,
)
from .elasticsearch_systeminfo import (
    ElasticSearchSystemInfo,
    ElasticSearchSystemInfoTypedDict,
)
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class ElasticSearchTypedDict(TypedDict):
    error_message: NotRequired[ElasticSearchErrorMessageTypedDict]
    results_node_info: NotRequired[ElasticSearchResultsNodeInfoTypedDict]
    system_info: NotRequired[ElasticSearchSystemInfoTypedDict]


class ElasticSearch(BaseModel):
    error_message: Optional[ElasticSearchErrorMessage] = None

    results_node_info: Optional[ElasticSearchResultsNodeInfo] = None

    system_info: Optional[ElasticSearchSystemInfo] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .location import Location, LocationTypedDict
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class LocationUpdatedTypedDict(TypedDict):
    location: NotRequired[LocationTypedDict]


class LocationUpdated(BaseModel):
    location: Optional[Location] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .collection import Collection, CollectionTypedDict
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class ResponseEnvelopeCollectionTypedDict(TypedDict):
    result: NotRequired[CollectionTypedDict]


class ResponseEnvelopeCollection(BaseModel):
    result: Optional[Collection] = None



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .oracle_descriptor import OracleDescriptor, OracleDescriptorTypedDict
from censys_platform.types import (
    BaseModel,
    Nullable,
    OptionalNullable,
    UNSET,
    UNSET_SENTINEL,
)
from pydantic import model_serializer
from typing import Dict, List, Optional
from typing_extensions import NotRequired, TypedDict


class OracleTypedDict(TypedDict):
    accept_version: NotRequired[int]
    r"""The version declared by the service when it accepts the handshake, if applicable."""
    connect_flags0: NotRequired[Dict[str, bool]]
    r"""The first set of ConnectFlags returned in the Accept packet."""
    connect_flags1: NotRequired[Dict[str, bool]]
    r"""The second set of ConnectFlags returned in the Accept packet."""
    did_resend: NotRequired[bool]
    r"""Whether the server requested that the scanner resend its initial connection packet."""
    global_service_options: NotRequired[Dict[str, bool]]
    r"""Set of flags that the server returns in the Accept packet."""
    nsn_service_versions: NotRequired[Dict[str, str]]
    r"""A map from the native Service Negotation service names to the ReleaseVersion (in dotted-decimal format) in that service packet."""
    nsn_version: NotRequired[str]
    r"""The version string in the root of the native service negotiation packet, if applicable."""
    refuse_error: NotRequired[Nullable[List[OracleDescriptorTypedDict]]]
    r"""The parsed descriptor returned by the server in the Refuse packet; it is empty if the server does not return a Refuse packet. The keys are strings like 'DESCRIPTION.ERROR_STACK.ERROR.CODE"""
    refuse_error_raw: NotRequired[str]
    r"""The unparsed error received when the initial handshake is refused."""
    refuse_reason_app: NotRequired[str]
    r"""The 'AppReason' returned by the server in the RefusePacket, as an 8-bit unsigned hex string."""
    refuse_reason_sys: NotRequired[str]
    r"""The 'SysReason' returned by the server in the RefusePacket, as an 8-bit unsigned hex string."""
    refuse_version: NotRequired[str]
    r"""The version declared by the service when it refuses the handshake, if applicable."""


class Oracle(BaseModel):
    accept_version: Optional[int] = None
    r"""The version declared by the service when it accepts the handshake, if applicable."""

    connect_flags0: Optional[Dict[str, bool]] = None
    r"""The first set of ConnectFlags returned in the Accept packet."""

    connect_flags1: Optional[Dict[str, bool]] = None
    r"""The second set of ConnectFlags returned in the Accept packet."""

    did_resend: Optional[bool] = None
    r"""Whether the server requested that the scanner resend its initial connection packet."""

    global_service_options: Optional[Dict[str, bool]] = None
    r"""Set of flags that the server returns in the Accept packet."""

    nsn_service_versions: Optional[Dict[str, str]] = None
    r"""A map from the native Service Negotation service names to the ReleaseVersion (in dotted-decimal format) in that service packet."""

    nsn_version: Optional[str] = None
    r"""The version string in the root of the native service negotiation packet, if applicable."""

    refuse_error: OptionalNullable[List[OracleDescriptor]] = UNSET
    r"""The parsed descriptor returned by the server in the Refuse packet; it is empty if the server does not return a Refuse packet. The keys are strings like 'DESCRIPTION.ERROR_STACK.ERROR.CODE"""

    refuse_error_raw: Optional[str] = None
    r"""The unparsed error received when the initial handshake is refused."""

    refuse_reason_app: Optional[str] = None
    r"""The 'AppReason' returned by the server in the RefusePacket, as an 8-bit unsigned hex string."""

    refuse_reason_sys: Optional[str] = None
    r"""The 'SysReason' returned by the server in the RefusePacket, as an 8-bit unsigned hex string."""

    refuse_version: Optional[str] = None
    r"""The version declared by the service when it refuses the handshake, if applicable."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = [
            "accept_version",
            "connect_flags0",
            "connect_flags1",
            "did_resend",
            "global_service_options",
            "nsn_service_versions",
            "nsn_version",
            "refuse_error",
            "refuse_error_raw",
            "refuse_reason_app",
            "refuse_reason_sys",
            "refuse_version",
        ]
        nullable_fields = ["refuse_error"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from censys_platform.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class ScreenshotTypedDict(TypedDict):
    extracted_text: NotRequired[str]
    handle: NotRequired[str]
    phash: NotRequired[str]


class Screenshot(BaseModel):
    extracted_text: Optional[str] = None

    handle: Optional[str] = None

    phash: Optional[str] = None
